#
# spec file for package gnome-mines
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gnome-mines
Version:        40.1
Release:        1.13
Summary:        Minesweeper Game for GNOME
License:        GPL-3.0-or-later
Group:          Amusements/Games/Board/Other
URL:            https://wiki.gnome.org/Mines
Source0:        https://download.gnome.org/sources/gnome-mines/40/%{name}-%{version}.tar.xz

BuildRequires:  appstream-glib
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson >= 0.37.1
BuildRequires:  pkgconfig
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0) >= 2.40.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.12
BuildRequires:  pkgconfig(libgnome-games-support-1)
BuildRequires:  pkgconfig(librsvg-2.0) >= 2.32.0
BuildRequires:  pkgconfig(vapigen)

%description
This is the popular logic puzzle minesweeper, which includes avoiding
mines while receiving clues for the location of the mines.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%check
%meson_test

%files
%license COPYING
%doc NEWS
%doc %{_datadir}/help/C/%{name}/
%{_bindir}/%{name}
%{_datadir}/%{name}/
%{_datadir}/applications/org.gnome.Mines.desktop
%{_datadir}/glib-2.0/schemas/org.gnome.Mines.gschema.xml
%{_datadir}/icons/hicolor/*/apps/org.gnome.Mines*
%{_mandir}/man6/%{name}.6%{?ext_man}
%{_datadir}/metainfo/org.gnome.Mines.appdata.xml

%files lang -f %{name}.lang

%changelog
* Fri Feb 18 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 40.1:
  + Updated icon.
  + Added missing type parameter.
  + Fixed proprietary license in appdata.
  + Fixed build failure with latest meson.
  + Updated translations.
- Drop 0a10c3a8ae4395c8059875bcea74be5c17ef9a21.patch: Fixed
  upstream.
* Wed Feb  2 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add 0a10c3a8ae4395c8059875bcea74be5c17ef9a21.patch: Fix build
  with meson 0.60 and newer.
- Add appstream-glib and desktop-file-utils BuildRequires and add a
  check section and meson_test macro, validate desktop filea and
  metainfo during build.
* Sat Mar 20 2021 Michael Gorse <mgorse@suse.com>
- Update to version 40.0:
  + Updated translations.
* Thu Mar 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.rc:
  + Updated translations.
* Tue Jan 12 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 40.alpha:
  + Updated help.
  + Code cleanup and modernization.
  + Keyboard shortcuts window improvements.
  + Only allow long-press gesture on touchscreen.
  + Fixed icon in scores dialog.
  + Fixed incorrectly accepting game as won.
  + Fixed spacebar not working until other key is pressed.
  + Fixed timer not stopping when game ends with multi-release.
  + Updated translations.
* Sun Aug  9 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.1:
  + Only allow long-press gesture on touchscreens.
  + Fixed issue incorrectly accepting game as won.
  + Updated translations.
* Sun Mar  8 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.36.0:
  + Updated help.
  + Updated translations.
* Wed Feb 12 2020 dimstar@opensuse.org
- Update to version 3.35.90:
  + Removed overmine warnings feature.
  + Support for long-press flagging on touchscreens.
  + Updated help.
  + Updated translations.
* Tue Sep 10 2019 mgorse@suse.com
- Update to version 3.34.0:
  + Updated translations.
* Mon Sep  2 2019 mgorse@suse.com
- Update to version 3.33.92:
  + Updated translations.
  + Added README.
* Tue May  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.2:
  + Show keyboard cursor with bgcolors theme.
  + Updated translations.
* Fri Apr  5 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update License to GPL-3.0-or-later.
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.32.0:
  + Updated translations.
* Tue Mar  5 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 3.31.92:
  + Updated translations.
* Wed Feb 20 2019 bjorn.lie@gmail.com
- Update to version 3.31.91:
  + Updated translations.
* Sat Feb 16 2019 bjorn.lie@gmail.com
- Update to version 3.31.90:
  + Added suggested appdata tags.
  + Tests to validate appdata and desktop.
  + Keyboard shortcuts page.
  + Automated builds using Gitlab CI.
  + Updated application icon.
  + Snap packaging updates.
  + Added in-game shortcuts to keyboard shortcuts window.
  + Updated translations.
* Tue Jan  8 2019 bjorn.lie@gmail.com
- Update to version 3.31.4.1:
  + Fixed crash when opening appearance dialog.
  + Add libmath dependency to possibly fix linking issues.
- Drop update-desktop-files BuildRequires and macro: No longer
  needed.
* Mon Jan  7 2019 bjorn.lie@gmail.com
- Update to version 3.31.4:
  + Avoid unnecessary icon regeneration.
  + Extend css to cover tile theme images.
  + Fixed initial aspect ratio issues.
  + Change default theme to bgcolors.
  + Remove transitions for a snappier experience.
  + Add Keyboard shortcuts overlay.
  + Code cleanup.
  + Updated translations.
* Sat Jan  5 2019 bjorn.lie@gmail.com
- Update to version 3.31.3:
  + Avoid unnecessary icon regeneration.
  + Extend css to cover tile theme images.
  + Fixed initial aspect ratio issues.
  + Change default theme to bgcolors.
  + Remove transitions for a snappier experience.
  + Add Keyboard shortcuts overlay.
  + Code cleanup.
  + Updated translations.
- Changes from version 3.31.1:
  + Appmenu removal.
  + Code cleanup.
  + Enjoy the victory after winning.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1.1:
  + Fixed invisible flag.
* Wed Sep 26 2018 bjorn.lie@gmail.com
- Update to version 3.30.1:
  + Install 256x256 icon.
  + Updated translations.
* Sat Sep  8 2018 antoine.belvire@opensuse.org
- Update to version 3.30.0:
  + Updated translations.
  + Help cleanup.
  + Flatpak dependency urls updated to gitlab.
- Remove lang package from recommended packages as it already
  supplements main package (same effect, it's redundant).
* Sat Jun 23 2018 luc14n0@linuxmail.org
- Update to version 3.29.3:
  + Updated translations.
* Tue Mar 13 2018 dimstar@opensuse.org
- Update to version 3.28.0:
  + Updated translations.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92.1:
  + Include meson build files in the tarball.
* Tue Mar  6 2018 dimstar@opensuse.org
- Update to version 3.27.92:
  + Fixed icon install dir.
  + Install appdata to non-deprecated location.
  + Updated translations.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Feb  5 2018 luc14n0@linuxmail.org
- Update to version 3.27.90:
  + Fixed icon redraw issues.
  + Added snap packaging.
  + Updated translations.
- Update Url tag to https://wiki.gnome.org/Mines: current Mines'
  web page.
- Drop intltool BuildRequires following upstream migration to
  Gettext.
- Drop %%glib2_gsettings_schema_post, %%desktop_database_post,
  %%icon_theme_cache_post post/postun scriptlets and
  %%glib2_gsettings_schema_requires macro: they are no longer needed
  since RPM File Triggers.
- Add meson BuildRequires and replace configure, make and
  make_install macros with meson, meson_build and meson_install,
  reflecting upstream port to Meson build system.
- Add gee-0.8 and vapigen pkgconfig modules BuildRequires: new
  dependencies.
* Tue Nov 14 2017 fezhang@suse.com
- Update to version 3.27.2:
  + Updated translations.
* Tue Sep 12 2017 luc14n0@linuxmail.org
- Update to version 3.26.0:
  + Updated translations.
* Wed Sep  6 2017 luc14n0@linuxmail.org
- Update to version 3.25.92:
  + Updated translations.
* Tue Aug 22 2017 zaitor@opensuse.org
- Update to version 3.25.91:
  + Updated translations.
* Tue Aug 15 2017 dimstar@opensuse.org
- Update to version 3.25.90:
  + Fixed Bugzilla submit bug button text.
  + Use glib preset for i18n.
  + Build changes.
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 3.25.2:
  + Added flatpak manifest.
  + Added meson build rules.
  + Updated translations.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 3.24.0:
  + Updated translations.
* Mon Feb 27 2017 zaitor@opensuse.org
- Update to version 3.23.91:
  + Updated translations.
* Tue Nov 22 2016 dimstar@opensuse.org
- Update to version 3.23.2:
  + Use start-time mine randomization.
  + Removed deprecated calls.
  + Updated translations.
* Fri Nov 11 2016 firebird209@gmail.com
- Update to version 3.22.2:
  + Updated translations.
* Mon Oct 10 2016 zaitor@opensuse.org
- Update to version 3.22.1:
  + Updated translations.
* Mon Sep 19 2016 zaitor@opensuse.org
- Update to version 3.22.0:
  + Added content ratings.
  + Updated translations.
* Tue Sep 13 2016 zaitor@opensuse.org
- Update to version 3.21.92:
  + Updated translations.
* Mon Aug 29 2016 zaitor@opensuse.org
- Update to version 3.21.91:
  + libgnome-games-support dep change fixes.
  + Updated translations.
- Replace pkgconfig(libgnome-games-support-1.0) BuildRequires with
  pkgconfig(libgnome-games-support-1) following upstream.
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 3.21.90.1:
  + Build with new libgnome-games-support.
- Changes from version 3.21.90:
  + Appdata updates.
  + Updated translations.
- Replace pkgconfig(libgames-support-1.0) BuildRequires with
  pkgconfig(libgnome-games-support-1.0), following upstreams port.
* Tue Jun 21 2016 zaitor@opensuse.org
- Update to version 3.21.3:
  + Smaller minimum tile size to fit larger boards on fullHD.
  + Disable accels on the custom game screen.
  + Use libgames-support for score tracking.
- Add pkgconfig(libgames-support-1.0) BuildRequires: New
  dependency.
* Wed Jun 15 2016 zaitor@opensuse.org
- Update to version 3.20.1:
  + Can not enter custom size (bgo#766145).
  + Updated translations.
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 3.20.0:
  + Updated translations.
* Tue Mar 15 2016 dimstar@opensuse.org
- Update to version 3.19.91:
  + Fixed usage of deprecated icon name.
  + Updated translations.
* Tue Feb 16 2016 zaitor@opensuse.org
- Update to version 3.19.90:
  + Updated the Appdata to spec version 0.7+.
  + Fixed window size growing huge with GTK+ 3.20.
  + Updated translations.
* Tue Jan 19 2016 dimstar@opensuse.org
- Update to version 3.19.4:
  + Stop using deprecated gnome-common.
  + Add pre-commit and pre-applypatch hooks.
  + Updated translations.
* Wed Dec 23 2015 dimstar@opensuse.org
- Update to version 3.19.3:
  + Updated appdata and doap.
  + Updated translations.
* Tue Nov 24 2015 zaitor@opensuse.org
- Update to version 3.19.2:
  + Improved keyboard cursor display and behaviour.
  + Added extra keyboard shortcuts for starting/stopping games.
  + Change tile click behaviour to reveal tile on click release.
  + Fixed jumping clock issue in timer.
  + Show incorrectly flagged fields.
  + Updated translations.
- Changes from version 3.19.1:
  + Fixed timer reset and timer jumps.
  + Updated translations.
- Add fdupes BuildRequires and pass corresponding macro to remove
  duplicates.
- Stop obsoleting gnomine, no version supported in openSUSE ships
  this anymore.
* Tue Nov 10 2015 zaitor@opensuse.org
- Update to version 3.18.2:
  + Improved keyboard cursor display.
  + Added keyboard shortcuts to start/stop game.
  + Changed tile click to reveal on click release.
  + Fixed timer reset on game won.
  + Show incorrectly flagged fields.
  + Updated translations.
* Mon Oct 12 2015 zaitor@opensuse.org
- Update to version 3.18.1:
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 3.18.0:
  + Updated translations.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 3.17.92:
  + Updated translations.
* Wed Sep  2 2015 dimstar@opensuse.org
- Update to version 3.17.91:
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 3.17.90:
  + Updated translations.
* Tue Jul 21 2015 zaitor@opensuse.org
- Update to version 3.17.4:
  + Performance improvements.
  + Reduced high CPU usage after consecutive games.
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 3.17.3:
  + Added animations enable/disable checkbox.
  + Fixed unclickable spots between grid cells.
  + Updated translations.
* Wed May 27 2015 zaitor@opensuse.org
- Update to version 3.17.2:
  + Fixed keyboard navigation limits.
  + Updated translations.
* Wed Apr 15 2015 dimstar@opensuse.org
- Update to version 3.16.1:
  + Provide a symbolic icon.
  + Fixed theme selector initialization glitch.
  + Updated translations.
- Remove HighContrast %%icon_theme_cache_post(un) calls, as Symbolic
  icons have replaced them.
* Mon Mar 23 2015 dimstar@opensuse.org
- Update to version 3.16.0:
  + Updated translations.
* Tue Mar 17 2015 dimstar@opensuse.org
- Update to version 3.15.92:
  + Updated translations.
* Tue Mar  3 2015 dimstar@opensuse.org
- Update to version 3.15.91:
  + Updated translations.
* Tue Feb 17 2015 dimstar@opensuse.org
- Update to version 3.15.90:
  + Readded screen transitions.
  + Code cleanup.
  + Removed New Game from app menu.
  + Updated About dialog.
  + Connect to size_allocate.
  + Do not save size when tiled.
  + Updated translations.
* Mon Jan 26 2015 dimstar@opensuse.org
- Update to version 3.15.4:
  + Added support for themes and theme selector dialog.
  + Fixed distance between game area and sidebar buttons.
  + Removed hover effect from inactive tiles.
  + Do not hide any buttons.
  + Updated translations.
* Wed Dec 17 2014 zaitor@opensuse.org
- Update to version 3.15.3:
  + Use appstream-util for appdata validation.
  + Updated translations.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 3.14.1:
  + use XDG_CURRENT_DESKTOP to use/avoid headerbar.
  + Fixed sidebar resizing on game start glitch.
  + Updated translations.
* Tue Sep 23 2014 dimstar@opensuse.org
- Update to version 3.14.0:
  + Appdata: updated screenshot size.
  + Updated translations.
* Tue Sep 16 2014 zaitor@opensuse.org
- Update to version 3.13.92:
  + Don't translate timer labels.
  + Symbolic flag install path fixed.
  + Use new function for setting accelerators.
  + Updated translations.
* Mon Sep  1 2014 zaitor@opensuse.org
- Update to version 3.13.91:
  + Ignore the clock after exploding.
  + Updated translations.
* Mon Aug 18 2014 dimstar@opensuse.org
- Update to version 3.13.90:
  + High contrast icons.
  + Updated translations.
- Handle HighContrast icons in post/postun.
* Mon Jul 21 2014 dimstar@opensuse.org
- Update to version 3.13.4:
  + Theme tweaks for the latest Adwaita.
  + Fixed rough image rendering.
  + Do not use deprecated methods and properties.
  + Fixed styling issues causing diamonds to appear in the grid.
  + Fixed small flag icon.
  + Translatable clock label.
  + Better-looking minimum width request for the small board.
  + Don't show headerbar/appmenu on systems that don't support it.
  + Updated translations.
* Sat Jul 12 2014 dimstar@opensuse.org
- Update to version 3.13.2:
  + Update CSS style.
  + Flipped tiles should not appear sensitive on hover.
  + Scrollbars added for large custom minefields.
  + Use improved flag icon in right column.
  + Rename Difficulty button to Change Difficulty.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.13.1:
  + Use delayed settings saving.
  + New game screen improvements.
  + Custom game screen improvements.
  + Removed the preferences dialog.
  + Better minimum size request.
  + Reimplemented the minefield to be CSS stylable.
  + Moved user interface creating code to Glade UI files.
  + Added good-looking CSS style.
  + Updated help.
  + Updated translations.
* Sat May 17 2014 zaitor@opensuse.org
- Update to version 3.12.2:
  + Updated translations.
* Tue Apr 15 2014 zaitor@opensuse.org
- Update to version 3.12.1:
  + Updated translations.
* Mon Mar 24 2014 zaitor@opensuse.org
- Update to version 3.12.0:
  + Updated help.
  + Updated translations.
* Wed Mar 19 2014 dimstar@opensuse.org
- Update to version 3.11.92:
  + Appdata: update screenshot size.
  + Updated translations.
* Tue Feb 18 2014 zaitor@opensuse.org
- Update to version 3.11.90:
  + Appdata: specify project_group.
  + Rename desktop file to gnome-mines.desktop.
  + Hint time penalty now increases.
  + Add tooltips to buttons.
* Tue Dec 17 2013 dimstar@opensuse.org
- Update to version 3.11.3:
  + Move buttons to side of window.
  + Enable question flags by default.
  + Allow setting percentage of mines on the board in custom games.
  + Scores dialog: autoscroll to new score.
  + Scores dialog: replace Quit button with Close.
  + Updated translations.
* Wed Oct 30 2013 dimstar@opensuse.org
- Update to version 3.11.1:
  + Redesigned interface.
  + Remove BugBuddy support.
  + Updated translations.
* Sun Oct 13 2013 dimstar@opensuse.org
- Update to version 3.10.1:
  + Remove "Hint" action from app menu.
  + Updated translations.
* Mon Sep 23 2013 dimstar@opensuse.org
- Update to version 3.10.0:
  + Updated translations.
* Mon Sep 16 2013 zaitor@opensuse.org
- Update to version 3.9.92:
  + Add appdata file.
  + Updated translations.
* Wed Aug 21 2013 dimstar@opensuse.org
- Update to version 3.9.90:
  + Resize the window when switching to a smaller minefield.
  + Fix broken links and typos in user help.
  + Fix name of app menu when not launched by GNOME Shell.
  + Updated translations.
* Tue Aug 20 2013 dimstar@opensuse.org
- Update to version 3.8.2:
  + Help: update damned lies module name to gnome-mines.
  + Fix crash when releasing button outside minefield.
  + Updated translations.
* Mon Apr 15 2013 dimstar@opensuse.org
- Update to version 3.8.1:
  + Updated translations.
* Wed Mar 27 2013 dimstar@opensuse.org
- Update to version 3.8.0:
  + Updated translations.
* Tue Mar 19 2013 dimstar@opensuse.org
- Update to version 3.7.92:
  + Renamed desktop file back to gnomine.dekstop.
  + Increase number visibility.
  + Keyboard support.
  + Updated translations.
- Also obsolete gnomine-lang to ease upgrades.
* Tue Mar  5 2013 dimstar@opensuse.org
- Initial package, version 3.7.90: split-off from gnome-games.
